@@ -12,19 +12,21 @@ Net::OAuth::AccessTokenResponse - An OAuth protocol response for an Access Token
 
 =head1 SEE ALSO
 
-L<Net::OAuth::Response>, L<http://oauth.net>
+L<Net::OAuth>, L<http://oauth.net>
 
 =head1 AUTHOR
 
-Keith Grennan, C<< <kgrennan at cpan.org> >>
+Originally by Keith Grennan <kgrennan@cpan.org>
 
-=head1 COPYRIGHT & LICENSE
+Currently maintained by Robert Rothenberg <rrwo@cpan.org>
 
-Copyright 2007 Keith Grennan, all rights reserved.
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2007-2012, 2024-2025 Keith Grennan
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
