@@ -9,7 +9,9 @@ use Net::OAuth;
 use Net::OAuth::Message;
 use Net::OAuth::AccessToken;
 use Carp;
-use Crypt::URandom qw( urandom ),
+use Crypt::URandom qw( urandom );
+
+our $VERSION = '0.31';
 
 =head1 NAME
 
