@@ -6,6 +6,7 @@ use URI::Escape;
 use Net::OAuth;
 use URI;
 use URI::QueryParam;
+use Carp;
 
 use constant OAUTH_PREFIX => 'oauth_';
 
@@ -85,13 +86,13 @@ sub check {
     my $self = shift;
     foreach my $k (@{$self->required_message_params}, @{$self->required_api_params}) {
         if (not defined $self->{$k}) {
-            die "Missing required parameter '$k'";
+            croak "Missing required parameter '$k'";
         }
     }
     if ($self->{extra_params} and $self->allow_extra_params) {
         foreach my $k (keys %{$self->{extra_params}}) {
             if ($k =~ $OAUTH_PREFIX_RE) {
-                die "Parameter '$k' not allowed in arbitrary params"
+                croak "Parameter '$k' not allowed in arbitrary params"
             }
         }
     }
@@ -100,17 +101,12 @@ sub check {
 sub encode {
     my $str = shift;
     $str = "" unless defined $str;
-    if ($str =~ /[\x80-\xFF]/) {
-        Net::OAuth::smart_require('Encode');
-        no strict 'subs';
-        if (Encode::is_utf8($str)) {
-            # Avoid double-encoding UTF-8.
-            # Ideally the caller would have done this already
-            # But perl5 + unicode is very confusing, so try to be helpful..
-            $str = Encode::decode_utf8($str, 1);
+    unless($Net::OAuth::SKIP_UTF8_DOUBLE_ENCODE_CHECK) {
+        if ($str =~ /[\x80-\xFF]/ and !utf8::is_utf8($str)) {
+            warn "Net::OAuth warning: your OAuth message appears to contain some multi-byte characters that need to be decoded via Encode.pm or a PerlIO layer first.  This may result in an incorrect signature.";
         }
     }
-    return URI::Escape::uri_escape_utf8($str,'^\w.~-');
+    return URI::Escape::uri_escape_utf8($str);
 }
 
 sub decode {
@@ -140,7 +136,7 @@ sub gather_message_parameters {
         }
         if ($self->can('request_url')) {
             my $url = $self->request_url;
-            _ensure_uri_object($url);         
+            _ensure_uri_object($url);
             foreach my $k ($url->query_param) {
                 $params{$k} = $url->query_param($k);
             }
@@ -182,7 +178,7 @@ sub _signature_method_class {
     my $self = shift;
     (my $signature_method = $self->signature_method) =~ s/\W+/_/g;
     my $sm_class = 'Net::OAuth::SignatureMethod::' . $signature_method;
-    die "Unable to load $signature_method plugin" unless Net::OAuth::smart_require($sm_class);
+    croak "Unable to load $signature_method plugin" unless Net::OAuth::smart_require($sm_class);
     return $sm_class;
 }
 
@@ -204,7 +200,7 @@ sub from_authorization_header {
     my $proto = shift;
     my $header = shift;
     my $class = ref $proto || $proto;
-    die "Header must start with \"OAuth \"" unless $header =~ s/OAuth //;
+    croak "Header must start with \"OAuth \"" unless $header =~ s/OAuth //;
     my @header = split /[\s]*,[\s]*/, $header;
     shift @header if $header[0] =~ /^realm=/i;
     return $class->_from_pairs(\@header, @_)
@@ -214,7 +210,7 @@ sub _from_pairs() {
 	my $class = shift;
 	my $pairs = shift;
 	if (ref $pairs ne 'ARRAY') {
-		die 'Expected an array!';
+		croak 'Expected an array!';
 	}
 	my %params;
 	foreach my $pair (@$pairs) {
@@ -233,7 +229,7 @@ sub from_hash {
     my $class = ref $proto || $proto;
     my $hash = shift;
 	if (ref $hash ne 'HASH') {
-		die 'Expected a hash!';
+		croak 'Expected a hash!';
 	}
     my %api_params = @_;
     # need to do this earlier than Message->new because
@@ -244,7 +240,7 @@ sub from_hash {
     foreach my $k (keys %$hash) {
         if ($k =~ s/$OAUTH_PREFIX_RE//) {
             if (!grep ($_ eq $k, @{$class->all_message_params})) {
-               die "Parameter ". OAUTH_PREFIX ."$k not valid for a message of type $class\n";
+               croak "Parameter ". OAUTH_PREFIX ."$k not valid for a message of type $class";
             }
             else {
                 $msg_params{$k} = $hash->{OAUTH_PREFIX . $k};
@@ -252,7 +248,7 @@ sub from_hash {
         }
         elsif ($class->is_extension_param($k)) {
             if (!grep ($_ eq $k, @{$class->all_message_params})) {
-                die "Parameter $k not valid for a message of type $class\n";
+                croak "Parameter $k not valid for a message of type $class";
             }
             else {
                 $msg_params{$k} = $hash->{$k};
@@ -304,7 +300,7 @@ sub to_url {
 	if (defined $url) {
         _ensure_uri_object($url);
         $url = $url->clone; # don't modify the URL that was passed in
-        $url->query(undef); # remove any existing query params, as these may cause the signature to break	
+        $url->query(undef); # remove any existing query params, as these may cause the signature to break
 		my $params = $self->to_hash;
 		my $sep = '?';
 		foreach my $k (sort keys %$params) {
@@ -328,11 +324,13 @@ L<Net::OAuth>, L<http://oauth.net>
 
 =head1 AUTHOR
 
-Keith Grennan, C<< <kgrennan at cpan.org> >>
+Originally by Keith Grennan <kgrennan@cpan.org>
+
+Currently maintained by Robert Rothenberg <rrwo@cpan.org>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 Keith Grennan, all rights reserved.
+Copyright 2007-2012, 2024-2025 Keith Grennan
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
