@@ -1,9 +1,13 @@
 package Net::OAuth::ProtectedResourceRequest;
 use warnings;
 use strict;
-use base 'Net::OAuth::AccessTokenRequest';
+use base 'Net::OAuth::Request';
 
+__PACKAGE__->add_required_message_params(qw/token/);
+__PACKAGE__->add_required_api_params(qw/token_secret/);
 sub allow_extra_params {1}
+sub sign_message {1}
+
 
 =head1 NAME
 
@@ -15,11 +19,13 @@ L<Net::OAuth>, L<http://oauth.net>
 
 =head1 AUTHOR
 
-Keith Grennan, C<< <kgrennan at cpan.org> >>
+Originally by Keith Grennan <kgrennan@cpan.org>
+
+Currently maintained by Robert Rothenberg <rrwo@cpan.org>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 Keith Grennan, all rights reserved.
+Copyright 2007-2012, 2024-2025 Keith Grennan
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -27,4 +33,4 @@ under the same terms as Perl itself.
 =cut
 
 
-1;
\ No newline at end of file
+1;
