@@ -2,6 +2,7 @@ package Net::OAuth::UserAuthResponse;
 use warnings;
 use strict;
 use base 'Net::OAuth::Response';
+use Net::OAuth;
 
 sub allow_extra_params {1}
 
@@ -11,19 +12,21 @@ Net::OAuth::UserAuthResponse - An OAuth protocol response for an Access Token
 
 =head1 SEE ALSO
 
-L<Net::OAuth::UserAuthResponse>, L<http://oauth.net>
+L<Net::OAuth>, L<http://oauth.net>
 
 =head1 AUTHOR
 
-Keith Grennan, C<< <kgrennan at cpan.org> >>
+Originally by Keith Grennan <kgrennan@cpan.org>
+
+Currently maintained by Robert Rothenberg <rrwo@cpan.org>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 Keith Grennan, all rights reserved.
+Copyright 2007-2012, 2024-2025 Keith Grennan
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
